diff --git a/web/package.json b/web/package.json
index 82dcc8e22..11f21aaf1 100644
--- a/web/package.json
+++ b/web/package.json
@@ -136,7 +136,7 @@
     "path-fx": "^2.0.0",
     "pathfinding": "^0.4.18",
     "paths-js": "^0.4.9",
-    "pgadmin4-tree": "git+https://github.com/EnterpriseDB/pgadmin4-treeview/#bc66dff13c17f256355d4f2bf79e3458007868bc",
+    "pgadmin4-tree": "git+https://github.com/EnterpriseDB/pgadmin4-treeview/#ccf3327caaaeaf06e5e683b07330ba2555d79867",
     "postcss": "^8.2.15",
     "raf": "^3.4.1",
     "react": "^17.0.1",
diff --git a/web/pgadmin/static/js/tree/tree.js b/web/pgadmin/static/js/tree/tree.js
index 41835b3bf..175320b31 100644
--- a/web/pgadmin/static/js/tree/tree.js
+++ b/web/pgadmin/static/js/tree/tree.js
@@ -225,6 +225,10 @@ export class Tree {
     return this.tree.getItemFromDOM(domElem[0]);
   }
 
+  DOMFrom(item) {
+    return this.tree.getDOMFromItem(item);
+  }
+
   path(item) {
     if (item) return item.path;
   }
diff --git a/web/pgadmin/static/js/tree/tree_init.tsx b/web/pgadmin/static/js/tree/tree_init.tsx
index d7d015288..a9a6892e3 100644
--- a/web/pgadmin/static/js/tree/tree_init.tsx
+++ b/web/pgadmin/static/js/tree/tree_init.tsx
@@ -89,10 +89,9 @@ var initBrowserTree = async (pgBrowser) => {
 
   // Render Browser Tree
   await render(
-    <div>
       <FileTreeX model={treeModelX}
         onReady={itemHandle} create={create} remove={remove} update={update}/>
-     </div>, document.getElementById('tree'));
+     , document.getElementById('tree'));
 }
 
 module.exports = {
diff --git a/web/pgadmin/static/js/tree/tree_nodes.ts b/web/pgadmin/static/js/tree/tree_nodes.ts
index b8d5350f3..3d75067dd 100644
--- a/web/pgadmin/static/js/tree/tree_nodes.ts
+++ b/web/pgadmin/static/js/tree/tree_nodes.ts
@@ -72,39 +72,42 @@ export class ManageTreeNodes {
   })
 
   public readNode = (_path: string) => new Promise<string[]>((res, rej) => {
-      let temp_tree_path = _path;
-      let node = this.findNode(_path);
+    let temp_tree_path = _path,
+      node = this.findNode(_path),
+      base_url = pgAdmin.Browser.URL;
 
-      if (node && node.children.length > 0) {
-        if (!node.type === FileType.File) {
-          rej("It's a leaf node")
-        }
-        else {
-          if (node.children.length != 0) res(node.children)
-        }
+    if (node && node.children.length > 0) {
+      if (!node.type === FileType.File) {
+        rej("It's a leaf node")
+      }
+      else {
+        if (node.children.length != 0) res(node.children)
       }
+    }
 
-      var self = this;
+    var self = this;
 
-      async function loadData() {
-        let url = '';
-        if (_path == '/browser') {
-          url = url_for('browser.nodes');
-        } else {
-          let _parent_url = self.generate_url(_path);
-          if (node.metadata.data._pid == null ) {
-            url = node.metadata.data._type + '/children/' + node.metadata.data._id;
+    async function loadData() {
+      let url = '';
+      if (_path == '/browser') {
+        url = url_for('browser.nodes');
+      } else {
+        let _parent_url = self.generate_url(_path);
+        if (node.metadata.data._pid == null ) {
+          url = node.metadata.data._type + '/children/' + node.metadata.data._id;
+        }
+        else {
+          if (node.metadata.data._type.includes("coll-")) {
+            let _type = node.metadata.data._type.replace("coll-", "")
+            url = _type + '/nodes/' + _parent_url;
           }
           else {
-            if (node.metadata.data._type.includes("coll-")) {
-              let _type = node.metadata.data._type.replace("coll-", "")
-              url = _type + '/nodes/' + _parent_url;
-            }
-            else {
-              url = node.metadata.data._type + '/children/' + _parent_url + '/' + node.metadata.data._id;
-            }
+            url = node.metadata.data._type + '/children/' + _parent_url + '/' + node.metadata.data._id;
+          }
         }
 
+        url = base_url + url;
+
         temp_tree_path = node.path;
 
         if (node.metadata.data._type == 'server' && !node.metadata.data.connected) {
diff --git a/web/yarn.lock b/web/yarn.lock
index d5a455530..555bd27fa 100644
--- a/web/yarn.lock
+++ b/web/yarn.lock
@@ -7582,9 +7582,9 @@ performance-now@^2.1.0:
   resolved "https://registry.yarnpkg.com/performance-now/-/performance-now-2.1.0.tgz#6309f4e0e5fa913ec1c69307ae364b4b377c9e7b"
   integrity sha1-Ywn04OX6kT7BxpMHrjZLSzd8nns=
 
-"pgadmin4-tree@git+https://github.com/EnterpriseDB/pgadmin4-treeview/#bc66dff13c17f256355d4f2bf79e3458007868bc":
+"pgadmin4-tree@git+https://github.com/EnterpriseDB/pgadmin4-treeview/#ccf3327caaaeaf06e5e683b07330ba2555d79867":
   version "1.0.0"
-  resolved "git+https://github.com/EnterpriseDB/pgadmin4-treeview/#bc66dff13c17f256355d4f2bf79e3458007868bc"
+  resolved "git+https://github.com/EnterpriseDB/pgadmin4-treeview/#ccf3327caaaeaf06e5e683b07330ba2555d79867"
   dependencies:
     "@types/classnames" "^2.2.6"
     "@types/react" "^16.7.18"
